[orca/570658] Update regression tests up to role_radio_button.py



commit 1a763fb59d6737babecf9544c9f1fac163fe0c89
Author: Willie Walker <william walker sun com>
Date:   Mon May 18 16:41:14 2009 -0400

    Update regression tests up to role_radio_button.py
    
    Still need to do the tests from role_radio_menu_item.py on.
---
 test/harness/runone.sh                           |    4 +-
 test/keystrokes/gtk-demo/role_accel_label.py     |   13 +---
 test/keystrokes/gtk-demo/role_alert.py           |    2 -
 test/keystrokes/gtk-demo/role_check_box.py       |   14 +---
 test/keystrokes/gtk-demo/role_check_menu_item.py |    9 +--
 test/keystrokes/gtk-demo/role_column_header.py   |   77 +++++-----------------
 test/keystrokes/gtk-demo/role_combo_box.py       |   47 ++++----------
 test/keystrokes/gtk-demo/role_combo_box2.py      |   15 +----
 test/keystrokes/gtk-demo/role_dialog.py          |    9 +--
 test/keystrokes/gtk-demo/role_icon.py            |   32 ++-------
 test/keystrokes/gtk-demo/role_label.py           |   25 ++-----
 test/keystrokes/gtk-demo/role_menu.py            |   32 +--------
 test/keystrokes/gtk-demo/role_page_tab.py        |   17 +----
 test/keystrokes/gtk-demo/role_push_button.py     |   15 +---
 test/keystrokes/gtk-demo/role_radio_button.py    |   17 +----
 15 files changed, 72 insertions(+), 256 deletions(-)

diff --git a/test/keystrokes/gtk-demo/role_accel_label.py b/test/keystrokes/gtk-demo/role_accel_label.py
index bf7a705..a5a22b9 100644
--- a/test/keystrokes/gtk-demo/role_accel_label.py
+++ b/test/keystrokes/gtk-demo/role_accel_label.py
@@ -37,8 +37,7 @@ sequence.append(utils.AssertPresentationAction(
     "New menu item",
     ["BRAILLE LINE:  'gtk-demo Application UI Manager Frame MenuBar New(Control n)'",
      "     VISIBLE:  'New(Control n)', cursor=1",
-     "SPEECH OUTPUT: 'File menu'",
-     "SPEECH OUTPUT: 'New Control n'"]))
+     "SPEECH OUTPUT: 'File menu New Control n'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.  The following should be
@@ -51,11 +50,7 @@ sequence.append(utils.AssertPresentationAction(
     "New menu item Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application UI Manager Frame MenuBar New(Control n)'",
      "     VISIBLE:  'New(Control n)', cursor=1",
-     "SPEECH OUTPUT: 'File menu'",
-     "SPEECH OUTPUT: 'New'",
-     "SPEECH OUTPUT: 'Control n'",
-     "SPEECH OUTPUT: 'item 1 of 5'",
-     "SPEECH OUTPUT: 'n'"]))
+     "SPEECH OUTPUT: 'File menu New Control n item 1 of 5 n'"]))
 
 ########################################################################
 # Now, continue on down the menu.
@@ -67,7 +62,6 @@ sequence.append(utils.AssertPresentationAction(
     "Open menu item",
     ["BRAILLE LINE:  'gtk-demo Application UI Manager Frame MenuBar Open(Control o)'",
      "     VISIBLE:  'Open(Control o)', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Open Control o'"]))
 
 ########################################################################
@@ -80,7 +74,6 @@ sequence.append(utils.AssertPresentationAction(
     "Save menu item",
     ["BRAILLE LINE:  'gtk-demo Application UI Manager Frame MenuBar Save(Control s)'",
      "     VISIBLE:  'Save(Control s)', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Save Control s'"]))
 
 ########################################################################
@@ -93,7 +86,6 @@ sequence.append(utils.AssertPresentationAction(
     "Save As... menu item",
     ["BRAILLE LINE:  'gtk-demo Application UI Manager Frame MenuBar Save As...(Control s)'",
      "     VISIBLE:  'Save As...(Control s)', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Save As... Control s'"]))
 
 ########################################################################
@@ -106,7 +98,6 @@ sequence.append(utils.AssertPresentationAction(
     "Quit menu item",
     ["BRAILLE LINE:  'gtk-demo Application UI Manager Frame MenuBar Quit(Control q)'",
      "     VISIBLE:  'Quit(Control q)', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Quit Control q'"]))
 
 ########################################################################
diff --git a/test/keystrokes/gtk-demo/role_alert.py b/test/keystrokes/gtk-demo/role_alert.py
index ca436fe..0f9005f 100644
--- a/test/keystrokes/gtk-demo/role_alert.py
+++ b/test/keystrokes/gtk-demo/role_alert.py
@@ -42,7 +42,6 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  'OK Button', cursor=1", 
      "SPEECH OUTPUT: 'Information This message box has been popped up the following", 
      "number of times: 1'", 
-     "SPEECH OUTPUT: ''", 
      "SPEECH OUTPUT: 'OK button'"]))
 
 ########################################################################
@@ -82,7 +81,6 @@ sequence.append(utils.AssertPresentationAction(
      "BRAILLE LINE:  'gtk-demo Application Interactive Dialog Dialog Entry 1 Testing $l'",
      "     VISIBLE:  'Entry 1 Testing $l', cursor=16",
      "SPEECH OUTPUT: 'Interactive Dialog'",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Entry 1 text Testing selected'"]))
 
 ########################################################################
diff --git a/test/keystrokes/gtk-demo/role_check_box.py b/test/keystrokes/gtk-demo/role_check_box.py
index 942eecb..0d18bc5 100644
--- a/test/keystrokes/gtk-demo/role_check_box.py
+++ b/test/keystrokes/gtk-demo/role_check_box.py
@@ -35,8 +35,7 @@ sequence.append(utils.AssertPresentationAction(
     "Left resize check box unchecked plus panel context",
     ["BRAILLE LINE:  'gtk-demo Application Panes Frame Horizontal Panel < > Resize CheckBox'",
      "     VISIBLE:  '< > Resize CheckBox', cursor=1",
-     "SPEECH OUTPUT: 'Horizontal panel'",
-     "SPEECH OUTPUT: 'Resize check box not checked'"]))
+     "SPEECH OUTPUT: 'Horizontal panel Resize check box not checked'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.
@@ -48,8 +47,7 @@ sequence.append(utils.AssertPresentationAction(
     "Left resize check box unchecked Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Panes Frame Horizontal Panel < > Resize CheckBox'",
      "     VISIBLE:  '< > Resize CheckBox', cursor=1",
-     "SPEECH OUTPUT: 'Resize check box not checked'",
-     "SPEECH OUTPUT: 'Alt r'"]))
+     "SPEECH OUTPUT: 'Resize check box not checked Alt r'"]))
 
 ########################################################################
 # Now, change its state.
@@ -77,8 +75,7 @@ sequence.append(utils.AssertPresentationAction(
     "Left resize check box checked Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Panes Frame Horizontal Panel <x> Resize CheckBox'",
      "     VISIBLE:  '<x> Resize CheckBox', cursor=1",
-     "SPEECH OUTPUT: 'Resize check box checked'",
-     "SPEECH OUTPUT: 'Alt r'"]))
+     "SPEECH OUTPUT: 'Resize check box checked Alt r'"]))
 
 ########################################################################
 # Change the state back and move on to a few more check boxes.  The
@@ -104,7 +101,6 @@ sequence.append(utils.AssertPresentationAction(
     "Right resize check box checked",
     ["BRAILLE LINE:  'gtk-demo Application Panes Frame Horizontal Panel <x> Resize CheckBox'",
      "     VISIBLE:  '<x> Resize CheckBox', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Resize check box checked'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -145,8 +141,7 @@ sequence.append(utils.AssertPresentationAction(
     "Top resize check box checked plus panel context",
     ["BRAILLE LINE:  'gtk-demo Application Panes Frame Vertical Panel < > Resize CheckBox'",
      "     VISIBLE:  '< > Resize CheckBox', cursor=1",
-     "SPEECH OUTPUT: 'Vertical panel'",
-     "SPEECH OUTPUT: 'Resize check box not checked'"]))
+     "SPEECH OUTPUT: 'Vertical panel Resize check box not checked'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(TypeAction(" "))
@@ -181,7 +176,6 @@ sequence.append(utils.AssertPresentationAction(
     "Bottom resize check box checked",
     ["BRAILLE LINE:  'gtk-demo Application Panes Frame Vertical Panel <x> Resize CheckBox'",
      "     VISIBLE:  '<x> Resize CheckBox', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Resize check box checked'"]))
 
 sequence.append(utils.StartRecordingAction())
diff --git a/test/keystrokes/gtk-demo/role_check_menu_item.py b/test/keystrokes/gtk-demo/role_check_menu_item.py
index 5dd0f7a..0e18f0c 100644
--- a/test/keystrokes/gtk-demo/role_check_menu_item.py
+++ b/test/keystrokes/gtk-demo/role_check_menu_item.py
@@ -40,7 +40,6 @@ sequence.append(utils.AssertPresentationAction(
     "Bold check item",
     ["BRAILLE LINE:  'gtk-demo Application Application Window Frame MenuBar <x> Bold CheckItem(Control b)'",
      "     VISIBLE:  '<x> Bold CheckItem(Control b)', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Bold check item checked Control b'"]))
 
 ########################################################################
@@ -53,13 +52,7 @@ sequence.append(utils.AssertPresentationAction(
     "Bold check item Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Application Window Frame MenuBar <x> Bold CheckItem(Control b)'",
      "     VISIBLE:  '<x> Bold CheckItem(Control b)', cursor=1",
-     "SPEECH OUTPUT: 'Preferences menu'",
-     "SPEECH OUTPUT: 'Bold'",
-     "SPEECH OUTPUT: 'check item'",
-     "SPEECH OUTPUT: 'checked'",
-     "SPEECH OUTPUT: 'Control b'",
-     "SPEECH OUTPUT: 'item 3 of 3'",
-     "SPEECH OUTPUT: 'b'"]))
+     "SPEECH OUTPUT: 'Preferences menu Bold check item checked Control b item 3 of 3 b'"]))
 
 ########################################################################
 # Dismiss the menu and close the Application Window demo window
diff --git a/test/keystrokes/gtk-demo/role_column_header.py b/test/keystrokes/gtk-demo/role_column_header.py
index 17b74af..d54ce12 100644
--- a/test/keystrokes/gtk-demo/role_column_header.py
+++ b/test/keystrokes/gtk-demo/role_column_header.py
@@ -50,7 +50,6 @@ sequence.append(utils.AssertPresentationAction(
     "Severity column header",
     ["BRAILLE LINE:  'gtk-demo Application GtkListStore demo Frame ScrollPane Table Severity ColumnHeader'",
      "     VISIBLE:  'Severity ColumnHeader', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Severity column header'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -61,7 +60,6 @@ sequence.append(utils.AssertPresentationAction(
     "Description column header",
     ["BRAILLE LINE:  'gtk-demo Application GtkListStore demo Frame ScrollPane Table Description ColumnHeader'",
      "     VISIBLE:  'Description ColumnHeader', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Description column header'"]))
 
 ########################################################################
@@ -78,11 +76,8 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  'Table', cursor=1",
      "BRAILLE LINE:  'gtk-demo Application GtkListStore demo Frame ScrollPane Table Description ColumnHeader < > Fixed? 60482 Normal scrollable notebooks and hidden tabs'",
      "     VISIBLE:  'scrollable notebooks and hidden ', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'table'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Description column header'",
-     "SPEECH OUTPUT: 'Fixed? check box not checked  60482 Normal scrollable notebooks and hidden tabs'"]))
+     "SPEECH OUTPUT: 'Description column header Fixed? check box not checked 60482 Normal scrollable notebooks and hidden tabs'"]))
 
 ########################################################################
 # Now move to the cell to the left containing the word "Normal".
@@ -98,9 +93,7 @@ sequence.append(utils.AssertPresentationAction(
     "Normal cell",
     ["BRAILLE LINE:  'gtk-demo Application GtkListStore demo Frame ScrollPane Table Severity ColumnHeader Normal'",
      "     VISIBLE:  'Normal', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Severity column header'",
-     "SPEECH OUTPUT: 'Normal'"]))
+     "SPEECH OUTPUT: 'Severity column header Normal'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.
@@ -112,12 +105,8 @@ sequence.append(utils.AssertPresentationAction(
     "Normal cell basic Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application GtkListStore demo Frame ScrollPane Table Severity ColumnHeader < > Fixed? 60482 Normal scrollable notebooks and hidden tabs'",
      "     VISIBLE:  'Normal scrollable notebooks and ', cursor=1",
-     "SPEECH OUTPUT: 'table'",
-     "SPEECH OUTPUT: 'Severity'",
-     "SPEECH OUTPUT: 'cell'",
-     "SPEECH OUTPUT: 'Normal'",
-     "SPEECH OUTPUT: 'column 3 of 4'",
-     "SPEECH OUTPUT: 'row 1 of 14'"]))
+     "SPEECH OUTPUT: 'table Severity cell Normal'",
+     "SPEECH OUTPUT: 'column 3 of 4 row 1 of 14'"]))
 
 ########################################################################
 # Do a detailed "Where Am I" via KP_Enter.
@@ -132,22 +121,11 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  'Normal scrollable notebooks and ', cursor=1",
      "BRAILLE LINE:  'gtk-demo Application GtkListStore demo Frame ScrollPane Table Severity ColumnHeader < > Fixed? 60482 Normal scrollable notebooks and hidden tabs'",
      "     VISIBLE:  'Normal scrollable notebooks and ', cursor=1",
-     "SPEECH OUTPUT: 'table'",
-     "SPEECH OUTPUT: 'Severity'",
-     "SPEECH OUTPUT: 'cell'",
-     "SPEECH OUTPUT: 'Normal'",
-     "SPEECH OUTPUT: 'column 3 of 4'",
-     "SPEECH OUTPUT: 'row 1 of 14'",
-     "SPEECH OUTPUT: 'table'",
-     "SPEECH OUTPUT: 'Severity'",
-     "SPEECH OUTPUT: 'cell'",
-     "SPEECH OUTPUT: 'Normal'",
-     "SPEECH OUTPUT: 'column 3 of 4'",
-     "SPEECH OUTPUT: 'row 1 of 14'",
-     "SPEECH OUTPUT: 'check box not checked'",
-     "SPEECH OUTPUT: '60482'",
-     "SPEECH OUTPUT: 'Normal'",
-     "SPEECH OUTPUT: 'scrollable notebooks and hidden tabs'"]))
+     "SPEECH OUTPUT: 'table Severity cell Normal'",
+     "SPEECH OUTPUT: 'column 3 of 4 row 1 of 14'",
+     "SPEECH OUTPUT: 'table Severity cell Normal'",
+     "SPEECH OUTPUT: 'column 3 of 4 row 1 of 14'",
+     "SPEECH OUTPUT: 'check box not checked 60482 Normal scrollable notebooks and hidden tabs'"]))
 
 ########################################################################
 # Now move to the cell to the left containing the number "60482".
@@ -163,9 +141,7 @@ sequence.append(utils.AssertPresentationAction(
     "60482 cell",
     ["BRAILLE LINE:  'gtk-demo Application GtkListStore demo Frame ScrollPane Table Bug number ColumnHeader 60482'",
      "     VISIBLE:  '60482', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Bug number column header'",
-     "SPEECH OUTPUT: '60482'"]))
+     "SPEECH OUTPUT: 'Bug number column header 60482'"]))
 
 ########################################################################
 # Now move to the cell to the left containing the checkbox.
@@ -181,9 +157,7 @@ sequence.append(utils.AssertPresentationAction(
     "Checkbox cell",
     ["BRAILLE LINE:  'gtk-demo Application GtkListStore demo Frame ScrollPane Table Fixed? ColumnHeader < > Fixed?'",
      "     VISIBLE:  '< > Fixed?', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Fixed? column header'",
-     "SPEECH OUTPUT: 'check box not checked '"]))
+     "SPEECH OUTPUT: 'Fixed? column header check box not checked'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.
@@ -195,12 +169,8 @@ sequence.append(utils.AssertPresentationAction(
     "Checkbox cell basic Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application GtkListStore demo Frame ScrollPane Table Fixed? ColumnHeader < > Fixed? 60482 Normal scrollable notebooks and hidden tabs'",
      "     VISIBLE:  '< > Fixed? 60482 Normal scrollab', cursor=1",
-     "SPEECH OUTPUT: 'table'",
-     "SPEECH OUTPUT: 'Fixed?'",
-     "SPEECH OUTPUT: 'cell'",
-     "SPEECH OUTPUT: 'check box not checked'",
-     "SPEECH OUTPUT: 'column 1 of 4'",
-     "SPEECH OUTPUT: 'row 1 of 14'"]))
+     "SPEECH OUTPUT: 'table Fixed? cell check box not checked'",
+     "SPEECH OUTPUT: 'column 1 of 4 row 1 of 14'"]))
 
 ########################################################################
 # Do a detailed "Where Am I" via KP_Enter.
@@ -215,22 +185,11 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  '< > Fixed? 60482 Normal scrollab', cursor=1",
      "BRAILLE LINE:  'gtk-demo Application GtkListStore demo Frame ScrollPane Table Fixed? ColumnHeader < > Fixed? 60482 Normal scrollable notebooks and hidden tabs'",
      "     VISIBLE:  '< > Fixed? 60482 Normal scrollab', cursor=1",
-     "SPEECH OUTPUT: 'table'",
-     "SPEECH OUTPUT: 'Fixed?'",
-     "SPEECH OUTPUT: 'cell'",
-     "SPEECH OUTPUT: 'check box not checked'",
-     "SPEECH OUTPUT: 'column 1 of 4'",
-     "SPEECH OUTPUT: 'row 1 of 14'",
-     "SPEECH OUTPUT: 'table'",
-     "SPEECH OUTPUT: 'Fixed?'",
-     "SPEECH OUTPUT: 'cell'",
-     "SPEECH OUTPUT: 'check box not checked'",
-     "SPEECH OUTPUT: 'column 1 of 4'",
-     "SPEECH OUTPUT: 'row 1 of 14'",
-     "SPEECH OUTPUT: 'check box not checked'",
-     "SPEECH OUTPUT: '60482'",
-     "SPEECH OUTPUT: 'Normal'",
-     "SPEECH OUTPUT: 'scrollable notebooks and hidden tabs'"]))
+     "SPEECH OUTPUT: 'table Fixed? cell check box not checked'",
+     "SPEECH OUTPUT: 'column 1 of 4 row 1 of 14'",
+     "SPEECH OUTPUT: 'table Fixed? cell check box not checked'",
+     "SPEECH OUTPUT: 'column 1 of 4 row 1 of 14'",
+     "SPEECH OUTPUT: 'check box not checked 60482 Normal scrollable notebooks and hidden tabs'"]))
  
 ########################################################################
 # Close the GtkListStore demo
diff --git a/test/keystrokes/gtk-demo/role_combo_box.py b/test/keystrokes/gtk-demo/role_combo_box.py
index ad5b17b..e5da7de 100644
--- a/test/keystrokes/gtk-demo/role_combo_box.py
+++ b/test/keystrokes/gtk-demo/role_combo_box.py
@@ -38,8 +38,7 @@ sequence.append(utils.AssertPresentationAction(
      "BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Some stock icons Panel  ComboWarning Warning'",
      "     VISIBLE:  'Warning', cursor=1",
      "SPEECH OUTPUT: 'window'",
-     "SPEECH OUTPUT: 'Some stock icons panel'",
-     "SPEECH OUTPUT: 'Warning'"]))
+     "SPEECH OUTPUT: 'Some stock icons panel Warning'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.
@@ -51,11 +50,7 @@ sequence.append(utils.AssertPresentationAction(
     "Warning combo box item Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Some stock icons Panel  ComboWarning Warning'",
      "     VISIBLE:  'Warning', cursor=1",
-     "SPEECH OUTPUT: 'menu'",
-     "SPEECH OUTPUT: 'Warning'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'item 1 of 5'",
-     "SPEECH OUTPUT: ''"]))
+     "SPEECH OUTPUT: 'menu Warning  item 1 of 5 '"]))
 
 ########################################################################
 # Now arrow down and select the "New" item.
@@ -67,7 +62,6 @@ sequence.append(utils.AssertPresentationAction(
     "New combo box item",
     ["BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Some stock icons Panel  ComboWarning New'",
      "     VISIBLE:  'New', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'New'"]))
 
 ########################################################################
@@ -80,11 +74,7 @@ sequence.append(utils.AssertPresentationAction(
     "New combo box item Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Some stock icons Panel  ComboWarning New'",
      "     VISIBLE:  'New', cursor=1",
-     "SPEECH OUTPUT: 'menu'",
-     "SPEECH OUTPUT: 'New'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'item 3 of 5'",
-     "SPEECH OUTPUT: ''"]))
+     "SPEECH OUTPUT: 'menu New  item 3 of 5 '"]))
 
 ########################################################################
 # Select the "New" entry and tab to the editable text combo box.  Skip
@@ -100,8 +90,7 @@ sequence.append(utils.AssertPresentationAction(
      "BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Some stock icons Panel New Combo'",
      "     VISIBLE:  'New Combo', cursor=1",
      "SPEECH OUTPUT: 'Combo boxes frame'",
-     "SPEECH OUTPUT: 'Some stock icons panel'",
-     "SPEECH OUTPUT: 'New combo box'"]))
+     "SPEECH OUTPUT: 'Some stock icons panel New combo box'"]))
 
 sequence.append(KeyComboAction("Tab"))
 sequence.append(WaitForFocus("Boston", acc_role=pyatspi.ROLE_COMBO_BOX))
@@ -116,8 +105,7 @@ sequence.append(utils.AssertPresentationAction(
     "Editable text combo box",
     ["BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Editable Panel  $l'",
      "     VISIBLE:  ' $l', cursor=1",
-     "SPEECH OUTPUT: 'Editable panel'",
-     "SPEECH OUTPUT: 'text '"]))
+     "SPEECH OUTPUT: 'Editable panel text '"]))
 
 ########################################################################
 # Type "Four" in the text area.
@@ -154,10 +142,7 @@ sequence.append(utils.AssertPresentationAction(
     "Editable text combo box Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Editable Panel Four $l'",
      "     VISIBLE:  'Four $l', cursor=5",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'text'",
-     "SPEECH OUTPUT: 'Four'",
-     "SPEECH OUTPUT: ''"]))
+     "SPEECH OUTPUT: 'text Four'"]))
 
 ########################################################################
 # Tab to the triangular down arrow of the editable combo box.
@@ -169,7 +154,6 @@ sequence.append(utils.AssertPresentationAction(
     "Editable text combo box open button",
     ["BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Editable Panel Four Combo'",
      "     VISIBLE:  'Four Combo', cursor=5",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Four combo box'"]))
 
 ########################################################################
@@ -207,7 +191,6 @@ sequence.append(utils.AssertPresentationAction(
     "Editable text combo box with selected text",
     ["BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Editable Panel Four $l'",
      "     VISIBLE:  'Four $l', cursor=5",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'text Four selected'"]))
 
 ########################################################################
@@ -220,11 +203,8 @@ sequence.append(utils.AssertPresentationAction(
     "Editable text combo box with selected text Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Editable Panel Four $l'",
      "     VISIBLE:  'Four $l', cursor=5",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'text'",
-     "SPEECH OUTPUT: 'Four'",
-     "SPEECH OUTPUT: 'selected'",
-     "SPEECH OUTPUT: ''"]))
+     "SPEECH OUTPUT: 'text Four'",
+     "SPEECH OUTPUT: 'selected '"]))
 
 ########################################################################
 # Tab to the triangular down arrow of the editable combo box and open
@@ -241,10 +221,12 @@ sequence.append(utils.AssertPresentationAction(
     "Editable text combo box menu",
     ["BRAILLE LINE:  'gtk-demo Application Window'",
      "     VISIBLE:  'gtk-demo Application Window', cursor=22",
+     "BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Editable Panel Menu'",
+     "     VISIBLE:  'Menu', cursor=1",
      "BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Editable Panel  ComboFour One'",
      "     VISIBLE:  'One', cursor=1",
      "SPEECH OUTPUT: 'window'",
-     "SPEECH OUTPUT: 'Editable panel'",
+     "SPEECH OUTPUT: 'Editable panel menu'",
      "SPEECH OUTPUT: 'One'"]))
 
 ########################################################################
@@ -257,7 +239,6 @@ sequence.append(utils.AssertPresentationAction(
     "Editable text combo box One item",
     ["BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Editable Panel  ComboFour Two'",
      "     VISIBLE:  'Two', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Two'"]))
 
 ########################################################################
@@ -271,9 +252,8 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  'Combo boxes Frame', cursor=1",
      "BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Editable Panel Two Combo'",
      "     VISIBLE:  'Two Combo', cursor=1",
-     "SPEECH OUTPUT: 'Combo boxes frame'",
-     "SPEECH OUTPUT: 'Editable panel'",
-     "SPEECH OUTPUT: 'Two combo box'"]))
+     "SPEECH OUTPUT: 'Combo boxes frame",
+     "SPEECH OUTPUT: 'Editable panel Two combo box'"]))
 
 sequence.append(KeyComboAction("<Shift>ISO_Left_Tab"))
 sequence.append(WaitForFocus(acc_role=pyatspi.ROLE_TEXT))
@@ -287,7 +267,6 @@ sequence.append(utils.AssertPresentationAction(
     "Editable text combo box Two text selected",
     ["BRAILLE LINE:  'gtk-demo Application Combo boxes Frame Editable Panel Two $l'",
      "     VISIBLE:  'Two $l', cursor=4",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'text Two selected'"]))
 
 ########################################################################
diff --git a/test/keystrokes/gtk-demo/role_combo_box2.py b/test/keystrokes/gtk-demo/role_combo_box2.py
index f0d94fe..64a17fc 100644
--- a/test/keystrokes/gtk-demo/role_combo_box2.py
+++ b/test/keystrokes/gtk-demo/role_combo_box2.py
@@ -40,8 +40,7 @@ sequence.append(utils.AssertPresentationAction(
     "All sheets combo box item",
     ["BRAILLE LINE:  'gtk-demo Application Print Dialog TabList Page Setup Page Layout Filler Only print: All sheets Combo'",
      "     VISIBLE:  'All sheets Combo', cursor=1",
-     "SPEECH OUTPUT: 'Layout'",
-     "SPEECH OUTPUT: 'Only print: All sheets combo box'"]))
+     "SPEECH OUTPUT: 'Layout Only print: All sheets combo box'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.
@@ -53,11 +52,7 @@ sequence.append(utils.AssertPresentationAction(
     "All sheets combo box item Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Print Dialog TabList Page Setup Page Layout Filler Only print: All sheets Combo'",
      "     VISIBLE:  'All sheets Combo', cursor=1",
-     "SPEECH OUTPUT: 'Only print:'",
-     "SPEECH OUTPUT: 'combo box'",
-     "SPEECH OUTPUT: 'All sheets'",
-     "SPEECH OUTPUT: 'item 1 of 3'",
-     "SPEECH OUTPUT: 'Alt o'"]))
+     "SPEECH OUTPUT: 'Only print: combo box All sheets item 1 of 3 Alt o'"]))
 
 ########################################################################
 # Down arrow to select the "Even sheets" item in the combo box.
@@ -85,11 +80,7 @@ sequence.append(utils.AssertPresentationAction(
     "Even sheets combo box item Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Print Dialog TabList Page Setup Page Layout Filler Only print: Even sheets Combo'",
      "     VISIBLE:  'Even sheets Combo', cursor=1",
-     "SPEECH OUTPUT: 'Only print:'",
-     "SPEECH OUTPUT: 'combo box'",
-     "SPEECH OUTPUT: 'Even sheets'",
-     "SPEECH OUTPUT: 'item 2 of 3'",
-     "SPEECH OUTPUT: 'Alt o'"]))
+     "SPEECH OUTPUT: 'Only print: combo box Even sheets item 2 of 3 Alt o'"]))
 
 ########################################################################
 # Put things back the way they were and close the demo.
diff --git a/test/keystrokes/gtk-demo/role_dialog.py b/test/keystrokes/gtk-demo/role_dialog.py
index 7d44854..65292ba 100644
--- a/test/keystrokes/gtk-demo/role_dialog.py
+++ b/test/keystrokes/gtk-demo/role_dialog.py
@@ -43,11 +43,8 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  'GtkExpander Dialog', cursor=1",
      "BRAILLE LINE:  'gtk-demo Application GtkExpander Dialog & y Details ToggleButton'",
      "     VISIBLE:  '& y Details ToggleButton', cursor=1",
-     "SPEECH OUTPUT: 'Widget (double click for demo) column header'",
-     "SPEECH OUTPUT: 'Expander'",
-     "SPEECH OUTPUT: 'tree level 1'",
+     "SPEECH OUTPUT: 'Widget (double click for demo) page Widget (double click for demo) column header Expander tree level 1'",
      "SPEECH OUTPUT: 'GtkExpander Expander demo. Click on the triangle for details.'",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Details toggle button not pressed'"]))
 
 ########################################################################
@@ -60,9 +57,7 @@ sequence.append(utils.AssertPresentationAction(
     "Dialog Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application GtkExpander Dialog & y Details ToggleButton'",
      "     VISIBLE:  '& y Details ToggleButton', cursor=1",
-     "SPEECH OUTPUT: 'Details'",
-     "SPEECH OUTPUT: 'toggle button'",
-     "SPEECH OUTPUT: 'not pressed'"]))
+     "SPEECH OUTPUT: 'Details toggle button not pressed'"]))
 
 ########################################################################
 # Now close the demo and leave.
diff --git a/test/keystrokes/gtk-demo/role_icon.py b/test/keystrokes/gtk-demo/role_icon.py
index 769eaf8..0e95ddf 100644
--- a/test/keystrokes/gtk-demo/role_icon.py
+++ b/test/keystrokes/gtk-demo/role_icon.py
@@ -50,11 +50,8 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  'GtkIconView demo Frame', cursor=1",
      "BRAILLE LINE:  'gtk-demo Application GtkIconView demo Frame ScrollPane LayeredPane'",
      "     VISIBLE:  'LayeredPane', cursor=1",
-     "SPEECH OUTPUT: 'Widget (double click for demo) column header'",
-     "SPEECH OUTPUT: 'Icon View Basics'",
-     "SPEECH OUTPUT: 'tree level 2'",
+     "SPEECH OUTPUT: 'Widget (double click for demo) page Widget (double click for demo) column header Icon View Basics tree level 2'",
      "SPEECH OUTPUT: 'GtkIconView demo frame'",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'layered pane'"]))
 
 ########################################################################
@@ -67,10 +64,7 @@ sequence.append(utils.AssertPresentationAction(
     "Layered pane Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application GtkIconView demo Frame ScrollPane LayeredPane'",
      "     VISIBLE:  'LayeredPane', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'layered pane'",
-     "SPEECH OUTPUT: '0 of [0-9]+ items selected'",
-     "SPEECH OUTPUT: 'on item 0 of [0-9]+'"]))
+     "SPEECH OUTPUT: 'layered pane 0 of [0-9]+ items selected on item 0 of [0-9]+'"]))
 
 ########################################################################
 # Down into the icon list, finally making something be selected in the
@@ -83,9 +77,7 @@ sequence.append(utils.AssertPresentationAction(
     "bin icon",
     ["BRAILLE LINE:  'gtk-demo Application GtkIconView demo Frame ScrollPane LayeredPane bin Icon'",
      "     VISIBLE:  'bin Icon', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'bin icon'",
-     "SPEECH OUTPUT: ' not selected'"]))
+     "SPEECH OUTPUT: 'bin icon not selected'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.
@@ -97,10 +89,7 @@ sequence.append(utils.AssertPresentationAction(
     "bin icon Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application GtkIconView demo Frame ScrollPane LayeredPane bin Icon'",
      "     VISIBLE:  'bin Icon', cursor=1",
-     "SPEECH OUTPUT: 'Icon panel'",
-     "SPEECH OUTPUT: 'bin'",
-     "SPEECH OUTPUT: '[0-9] of [0-9]+ items selected'",
-     "SPEECH OUTPUT: 'on item 1 of [0-9]+'"]))
+     "SPEECH OUTPUT: 'Icon panel bin [0-9] of [0-9]+ items selected on item 1 of [0-9]+'"]))
 
 ########################################################################
 # Arrow right and wait for the next icon to be selected.
@@ -112,9 +101,7 @@ sequence.append(utils.AssertPresentationAction(
     "boot icon",
     ["BRAILLE LINE:  'gtk-demo Application GtkIconView demo Frame ScrollPane LayeredPane boot Icon'",
      "     VISIBLE:  'boot Icon', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'boot icon'",
-     "SPEECH OUTPUT: ' not selected'"]))
+     "SPEECH OUTPUT: 'boot icon not selected'"]))
 
 ########################################################################
 # Select more than one icon by doing Shift+Right.
@@ -126,9 +113,7 @@ sequence.append(utils.AssertPresentationAction(
     "icon selection",
     ["BRAILLE LINE:  'gtk-demo Application GtkIconView demo Frame ScrollPane LayeredPane bin Icon'",
      "     VISIBLE:  'bin Icon', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'bin icon'",
-     "SPEECH OUTPUT: ' not selected'"]))
+     "SPEECH OUTPUT: 'bin icon not selected'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.
@@ -140,10 +125,7 @@ sequence.append(utils.AssertPresentationAction(
     "icon selection Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application GtkIconView demo Frame ScrollPane LayeredPane bin Icon'",
      "     VISIBLE:  'bin Icon', cursor=1",
-     "SPEECH OUTPUT: 'Icon panel'",
-     "SPEECH OUTPUT: 'bin'",
-     "SPEECH OUTPUT: '[0-9] of [0-9]+ items selected'",
-     "SPEECH OUTPUT: 'on item 1 of [0-9]+'"]))
+     "SPEECH OUTPUT: 'Icon panel bin [0-9] of [0-9]+ items selected on item 1 of [0-9]+'"]))
 
 ########################################################################
 # Close the GtkIconView demo window
diff --git a/test/keystrokes/gtk-demo/role_label.py b/test/keystrokes/gtk-demo/role_label.py
index cb20b29..cc7d0b6 100644
--- a/test/keystrokes/gtk-demo/role_label.py
+++ b/test/keystrokes/gtk-demo/role_label.py
@@ -49,7 +49,6 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  'This message box has been popped', cursor=1",
      "BRAILLE LINE:  'gtk-demo Application Information Alert number of times: $l'",
      "     VISIBLE:  'number of times: $l', cursor=17",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'This message box has been popped up the following",
      "number of times: label'",
      "SPEECH OUTPUT: 'selected'"]))
@@ -65,9 +64,7 @@ sequence.append(utils.AssertPresentationAction(
     ["BRAILLE LINE:  'gtk-demo Application Information Alert number of times: $l'",
      "     VISIBLE:  'number of times: $l', cursor=17",
      "SPEECH OUTPUT: 'This message box has been popped up the following",
-     "number of times:'",
-     "SPEECH OUTPUT: 'selected'",
-     "SPEECH OUTPUT: 'label'"]))
+     "number of times: selected label'"]))
 
 ########################################################################
 # Do an extended "Where Am I" via double KP_Enter.
@@ -83,13 +80,9 @@ sequence.append(utils.AssertPresentationAction(
      "BRAILLE LINE:  'gtk-demo Application Information Alert number of times: $l'",
      "     VISIBLE:  'number of times: $l', cursor=17",
      "SPEECH OUTPUT: 'This message box has been popped up the following",
-     "number of times:'",
-     "SPEECH OUTPUT: 'selected'",
-     "SPEECH OUTPUT: 'label'",
+     "number of times: selected label'",
      "SPEECH OUTPUT: 'This message box has been popped up the following",
-     "number of times:'",
-     "SPEECH OUTPUT: 'selected'",
-     "SPEECH OUTPUT: 'label'"]))
+     "number of times: selected label'"]))
 
 ########################################################################
 # Position the caret at the beginning of the label and move right one
@@ -141,9 +134,7 @@ sequence.append(utils.AssertPresentationAction(
     ["BRAILLE LINE:  'gtk-demo Application Information Alert This message box has been popped up the following $l'",
      "     VISIBLE:  'This message box has been popped', cursor=5",
      "SPEECH OUTPUT: 'This message box has been popped up the following",
-     "number of times:'",
-     "SPEECH OUTPUT: 'selected'",
-     "SPEECH OUTPUT: 'label'"]))
+     "number of times: selected label'"]))
 
 ########################################################################
 # Do an extended "Where Am I" via double KP_Enter.
@@ -159,13 +150,9 @@ sequence.append(utils.AssertPresentationAction(
      "BRAILLE LINE:  'gtk-demo Application Information Alert This message box has been popped up the following $l'",
      "     VISIBLE:  'This message box has been popped', cursor=5",
      "SPEECH OUTPUT: 'This message box has been popped up the following",
-     "number of times:'",
-     "SPEECH OUTPUT: 'selected'",
-     "SPEECH OUTPUT: 'label'",
+     "number of times: selected label'",
      "SPEECH OUTPUT: 'This message box has been popped up the following",
-     "number of times:'",
-     "SPEECH OUTPUT: 'selected'",
-     "SPEECH OUTPUT: 'label'"]))
+     "number of times: selected label'"]))
 
 ########################################################################
 # Arrow left to clear the selection and then do a Shift+Control+Left to
diff --git a/test/keystrokes/gtk-demo/role_menu.py b/test/keystrokes/gtk-demo/role_menu.py
index 72b7daf..faa8133 100644
--- a/test/keystrokes/gtk-demo/role_menu.py
+++ b/test/keystrokes/gtk-demo/role_menu.py
@@ -36,7 +36,6 @@ sequence.append(utils.AssertPresentationAction(
     "File menu",
     ["BRAILLE LINE:  'gtk-demo Application Application Window Frame File Menu'",
      "     VISIBLE:  'File Menu', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'File menu'"]))
 
 ########################################################################
@@ -49,12 +48,7 @@ sequence.append(utils.AssertPresentationAction(
     "File menu Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Application Window Frame File Menu'",
      "     VISIBLE:  'File Menu', cursor=1",
-     "SPEECH OUTPUT: 'menu bar'",
-     "SPEECH OUTPUT: 'File'",
-     "SPEECH OUTPUT: 'menu'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'item 1 of 3'",
-     "SPEECH OUTPUT: 'f'"]))
+     "SPEECH OUTPUT: 'menu bar File menu  item 1 of 3 f'"]))
 
 ########################################################################
 # Right arrow to the "Preferences" menu.
@@ -67,7 +61,6 @@ sequence.append(utils.AssertPresentationAction(
     "Preferences menu",
     ["BRAILLE LINE:  'gtk-demo Application Application Window Frame Preferences Menu'",
      "     VISIBLE:  'Preferences Menu', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Preferences menu'"]))
 
 ########################################################################
@@ -80,12 +73,7 @@ sequence.append(utils.AssertPresentationAction(
     "Preferences menu Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Application Window Frame Preferences Menu'",
      "     VISIBLE:  'Preferences Menu', cursor=1",
-     "SPEECH OUTPUT: 'menu bar'",
-     "SPEECH OUTPUT: 'Preferences'",
-     "SPEECH OUTPUT: 'menu'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'item 2 of 3'",
-     "SPEECH OUTPUT: 'p'"]))
+     "SPEECH OUTPUT: 'menu bar Preferences menu  item 2 of 3 p'"]))
 
 ########################################################################
 # Go down to the "Color" menu.
@@ -98,7 +86,6 @@ sequence.append(utils.AssertPresentationAction(
     "Color menu",
     ["BRAILLE LINE:  'gtk-demo Application Application Window Frame MenuBar Color Menu'",
      "     VISIBLE:  'Color Menu', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Color menu'"]))
 
 ########################################################################
@@ -111,12 +98,7 @@ sequence.append(utils.AssertPresentationAction(
     "Color menu Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Application Window Frame MenuBar Color Menu'",
      "     VISIBLE:  'Color Menu', cursor=1",
-     "SPEECH OUTPUT: 'Preferences menu'",
-     "SPEECH OUTPUT: 'Color'",
-     "SPEECH OUTPUT: 'menu'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'item 1 of 3'",
-     "SPEECH OUTPUT: 'c'"]))
+     "SPEECH OUTPUT: 'Preferences menu Color menu  item 1 of 3 c'"]))
 
 ########################################################################
 # Go down to the "Shape" menu.
@@ -129,7 +111,6 @@ sequence.append(utils.AssertPresentationAction(
     "Shape menu",
     ["BRAILLE LINE:  'gtk-demo Application Application Window Frame MenuBar Shape Menu'",
      "     VISIBLE:  'Shape Menu', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Shape menu'"]))
 
 ########################################################################
@@ -142,12 +123,7 @@ sequence.append(utils.AssertPresentationAction(
     "Shape menu Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Application Window Frame MenuBar Shape Menu'",
      "     VISIBLE:  'Shape Menu', cursor=1",
-     "SPEECH OUTPUT: 'Preferences menu'",
-     "SPEECH OUTPUT: 'Shape'",
-     "SPEECH OUTPUT: 'menu'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'item 2 of 3'",
-     "SPEECH OUTPUT: 's'"]))
+     "SPEECH OUTPUT: 'Preferences menu Shape menu  item 2 of 3 s'"]))
 
 ########################################################################
 # Dismiss the menu and close the Application Window demo window
diff --git a/test/keystrokes/gtk-demo/role_page_tab.py b/test/keystrokes/gtk-demo/role_page_tab.py
index e0659c1..2984beb 100644
--- a/test/keystrokes/gtk-demo/role_page_tab.py
+++ b/test/keystrokes/gtk-demo/role_page_tab.py
@@ -41,13 +41,9 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  'TabList', cursor=1",
      "BRAILLE LINE:  'gtk-demo Application Print Dialog General Page'",
      "     VISIBLE:  'General Page', cursor=1",
-     "SPEECH OUTPUT: 'Widget (double click for demo) column header'",
-     "SPEECH OUTPUT: 'Printing'",
-     "SPEECH OUTPUT: 'tree level 1'",
+     "SPEECH OUTPUT: 'Widget (double click for demo) page Widget (double click for demo) column header Printing tree level 1'",
      "SPEECH OUTPUT: 'Print Range Copies'",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'tab list'",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'General page'"]))
 
 ########################################################################
@@ -60,10 +56,7 @@ sequence.append(utils.AssertPresentationAction(
     "General page tab Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Print Dialog General Page'",
      "     VISIBLE:  'General Page', cursor=1",
-     "SPEECH OUTPUT: 'tab list'",
-     "SPEECH OUTPUT: 'General page'",
-     "SPEECH OUTPUT: 'item 1 of 2'",
-     "SPEECH OUTPUT: ''"]))
+     "SPEECH OUTPUT: 'tab list General page item 1 of 2 '"]))
 
 ########################################################################
 # Arrow Right to the "Page Setup" tab.
@@ -75,7 +68,6 @@ sequence.append(utils.AssertPresentationAction(
     "Page Setup page tab",
     ["BRAILLE LINE:  'gtk-demo Application Print Dialog Page Setup Page'",
      "     VISIBLE:  'Page Setup Page', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Page Setup page'"]))
 
 ########################################################################
@@ -88,10 +80,7 @@ sequence.append(utils.AssertPresentationAction(
     "Page Setup page tab Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Print Dialog Page Setup Page'",
      "     VISIBLE:  'Page Setup Page', cursor=1",
-     "SPEECH OUTPUT: 'tab list'",
-     "SPEECH OUTPUT: 'Page Setup page'",
-     "SPEECH OUTPUT: 'item 2 of 2'",
-     "SPEECH OUTPUT: ''"]))
+     "SPEECH OUTPUT: 'tab list Page Setup page item 2 of 2 '"]))
 
 ########################################################################
 # Close the demo
diff --git a/test/keystrokes/gtk-demo/role_push_button.py b/test/keystrokes/gtk-demo/role_push_button.py
index d47066e..6b45b14 100644
--- a/test/keystrokes/gtk-demo/role_push_button.py
+++ b/test/keystrokes/gtk-demo/role_push_button.py
@@ -39,12 +39,9 @@ sequence.append(utils.AssertPresentationAction(
      "     VISIBLE:  'Button Boxes Frame', cursor=1",
      "BRAILLE LINE:  'gtk-demo Application Button Boxes Frame Horizontal Button Boxes Panel Spread Panel OK Button'",
      "     VISIBLE:  'OK Button', cursor=1",
-     "SPEECH OUTPUT: 'Widget (double click for demo) column header'",
-     "SPEECH OUTPUT: 'Button Boxes'",
-     "SPEECH OUTPUT: 'tree level 1'",
+     "SPEECH OUTPUT: 'Widget (double click for demo) page Widget (double click for demo) column header Button Boxes tree level 1'",
      "SPEECH OUTPUT: 'Button Boxes frame'",
-     "SPEECH OUTPUT: 'Horizontal Button Boxes panel Spread panel'",
-     "SPEECH OUTPUT: 'OK button'"]))
+     "SPEECH OUTPUT: 'Horizontal Button Boxes panel Spread panel OK button'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.
@@ -56,9 +53,7 @@ sequence.append(utils.AssertPresentationAction(
     "OK button Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Button Boxes Frame Horizontal Button Boxes Panel Spread Panel OK Button'",
      "     VISIBLE:  'OK Button', cursor=1",
-     "SPEECH OUTPUT: 'OK'",
-     "SPEECH OUTPUT: 'button'",
-     "SPEECH OUTPUT: 'Alt o'"]))
+     "SPEECH OUTPUT: 'OK button Alt o'"]))
 
 ########################################################################
 # Tab to the Cancel button.
@@ -70,7 +65,6 @@ sequence.append(utils.AssertPresentationAction(
     "Cancel button",
     ["BRAILLE LINE:  'gtk-demo Application Button Boxes Frame Horizontal Button Boxes Panel Spread Panel Cancel Button'",
      "     VISIBLE:  'Cancel Button', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Cancel button'"]))
 
 ########################################################################
@@ -86,8 +80,7 @@ sequence.append(utils.AssertPresentationAction(
     "OK Edge button",
     ["BRAILLE LINE:  'gtk-demo Application Button Boxes Frame Horizontal Button Boxes Panel Edge Panel OK Button'",
      "     VISIBLE:  'OK Button', cursor=1",
-     "SPEECH OUTPUT: 'Edge panel'",
-     "SPEECH OUTPUT: 'OK button'"]))
+     "SPEECH OUTPUT: 'Edge panel OK button'"]))
 
 ########################################################################
 # Close the demo
diff --git a/test/keystrokes/gtk-demo/role_radio_button.py b/test/keystrokes/gtk-demo/role_radio_button.py
index 3532b47..ce94f42 100644
--- a/test/keystrokes/gtk-demo/role_radio_button.py
+++ b/test/keystrokes/gtk-demo/role_radio_button.py
@@ -35,8 +35,7 @@ sequence.append(utils.AssertPresentationAction(
     "All Pages radio button",
     ["BRAILLE LINE:  'gtk-demo Application Print Dialog TabList General Page Range Filler &=y All Pages RadioButton'",
      "     VISIBLE:  '&=y All Pages RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Range'",
-     "SPEECH OUTPUT: 'All Pages selected radio button'"]))
+     "SPEECH OUTPUT: 'Range All Pages selected radio button'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.
@@ -48,11 +47,7 @@ sequence.append(utils.AssertPresentationAction(
     "All Pages radio button Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Print Dialog TabList General Page Range Filler &=y All Pages RadioButton'",
      "     VISIBLE:  '&=y All Pages RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Range'",
-     "SPEECH OUTPUT: 'All Pages radio button'",
-     "SPEECH OUTPUT: 'selected'",
-     "SPEECH OUTPUT: 'item 1 of 3'",
-     "SPEECH OUTPUT: 'Alt a'"]))
+     "SPEECH OUTPUT: 'Range All Pages radio button selected item 1 of 3 Alt a'"]))
 
 ########################################################################
 # Down arrow to the "Pages:" radio button.
@@ -73,7 +68,6 @@ sequence.append(utils.AssertPresentationAction(
     ["KNOWN ISSUE - the radio button should be presented as selected.",
      "BRAILLE LINE:  'gtk-demo Application Print Dialog TabList General Page Range Filler & y Pages: RadioButton'",
      "     VISIBLE:  '& y Pages: RadioButton', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Pages: not selected radio button'"]))
 
 ########################################################################
@@ -86,11 +80,7 @@ sequence.append(utils.AssertPresentationAction(
     "Range radio button Where Am I",
     ["BRAILLE LINE:  'gtk-demo Application Print Dialog TabList General Page Range Filler &=y Pages: RadioButton'",
      "     VISIBLE:  '&=y Pages: RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Range'",
-     "SPEECH OUTPUT: 'Pages: radio button'",
-     "SPEECH OUTPUT: 'selected'",
-     "SPEECH OUTPUT: 'item 3 of 3'",
-     "SPEECH OUTPUT: 'Alt e'"]))
+     "SPEECH OUTPUT: 'Range Pages: radio button selected item 3 of 3 Alt e'"]))
 
 ########################################################################
 # Put everything back and close the demo.
@@ -103,7 +93,6 @@ sequence.append(utils.AssertPresentationAction(
     ["KNOWN ISSUE - the radio button should be presented as selected.",
      "BRAILLE LINE:  'gtk-demo Application Print Dialog TabList General Page Range Filler & y All Pages RadioButton'",
      "     VISIBLE:  '& y All Pages RadioButton', cursor=1",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'All Pages not selected radio button'"]))
 
 ########################################################################



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/test/harness/runone.sh b/test/harness/runone.sh
index 80a526d..ba7bd87 100755
--- a/test/harness/runone.sh
+++ b/test/harness/runone.sh
@@ -86,7 +86,7 @@ then
     source $PARAMS_FILE
 fi
 
 # Run the app (or gnome-terminal if no app was given) and let it settle in.
 #
 ARGS=""
 if [ -n "$3" ]
@@ -94,7 +94,7 @@ then
     APP_NAME=$2
     orcaRunning=$3
 else
-   APP_NAME=gnome-terminal
+   APP_NAME=gtk-demo
    if [ -n "$2" ]
    then
        orcaRunning=$2
@@ -86,7 +86,7 @@ then
 fi
 
-# Run the app (or gnome-terminal if no app was given) and let it settle in.
+# Run the app (or gtk-demo if no app was given) and let it settle in.
 #
 ARGS=""